@@ -1,7 +1,12 @@
 #! /usr/bin/python3 -i
 # coding=utf-8
 simplify={
+  "𧦧":"𫍟",
+  "𨬟":"𰾵",
   "𡑍":"𫭼",
+  "𥳁":"𥲤",
+  "𡐨":"壄",
+  "𣙜":"榷",
   "㑳":"㑇",
   "㑹":"会",
   "㘚":"㘎",
@@ -12,6 +17,7 @@ simplify={
   "㩁":"榷",
   "㩳":"㧐",
   "㫖":"旨",
+  "㬎":"显",
   "㮚":"栗",
   "㵎":"涧",
   "䃮":"鿎",
@@ -39,6 +45,7 @@ simplify={
   "亞":"亚",
   "仏":"佛",
   "伝":"传",
+  "佇":"伫",
   "佔":"占",
   "併":"并",
   "來":"来",
@@ -194,6 +201,7 @@ simplify={
   "啗":"啖",
   "啞":"哑",
   "啟":"启",
+  "喚":"唤",
   "喩":"喻",
   "喪":"丧",
   "喫":"吃",
@@ -342,6 +350,7 @@ simplify={
   "媧":"娲",
   "媼":"媪",
   "媽":"妈",
+  "嫋":"袅",
   "嫗":"妪",
   "嫵":"妩",
   "嫻":"娴",
@@ -353,9 +362,11 @@ simplify={
   "嬌":"娇",
   "嬙":"嫱",
   "嬡":"嫒",
+  "嬢":"娘",
   "嬪":"嫔",
   "嬰":"婴",
   "嬸":"婶",
+  "孃":"娘",
   "孌":"娈",
   "孫":"孙",
   "學":"学",
@@ -399,7 +410,9 @@ simplify={
   "島":"岛",
   "峽":"峡",
   "崍":"崃",
+  "崑":"昆",
   "崗":"岗",
+  "崙":"仑",
   "崧":"嵩",
   "崬":"岽",
   "嵐":"岚",
@@ -448,6 +461,7 @@ simplify={
   "広":"广",
   "庫":"库",
   "廁":"厕",
+  "廂":"厢",
   "廃":"废",
   "廄":"厩",
   "廎":"庼",
@@ -463,10 +477,12 @@ simplify={
   "廬":"庐",
   "廳":"厅",
   "廵":"巡",
+  "廻":"回",
   "弒":"弑",
   "弔":"吊",
   "張":"张",
   "強":"强",
+  "彃":"𪪼",
   "彄":"𫸩",
   "彆":"别",
   "彈":"弹",
@@ -491,7 +507,9 @@ simplify={
   "徵":"征",
   "徹":"彻",
   "応":"应",
+  "怳":"恍",
   "恆":"恒",
+  "恠":"怪",
   "恥":"耻",
   "恵":"惠",
   "悅":"悦",
@@ -590,6 +608,7 @@ simplify={
   "換":"换",
   "揮":"挥",
   "搆":"构",
+  "搉":"榷",
   "損":"损",
   "搖":"摇",
   "搗":"捣",
@@ -724,6 +743,7 @@ simplify={
   "棶":"梾",
   "椏":"桠",
   "検":"检",
+  "椷":"缄",
   "楊":"杨",
   "楓":"枫",
   "楡":"榆",
@@ -733,6 +753,7 @@ simplify={
   "楽":"乐",
   "榪":"杩",
   "榮":"荣",
+  "榲":"榅",
   "榿":"桤",
   "構":"构",
   "槍":"枪",
@@ -748,6 +769,7 @@ simplify={
   "標":"标",
   "樞":"枢",
   "樣":"样",
+  "樧":"榝",
   "権":"权",
   "樸":"朴",
   "樹":"树",
@@ -1031,6 +1053,7 @@ simplify={
   "狹":"狭",
   "狽":"狈",
   "猟":"猎",
+  "猨":"猿",
   "猶":"犹",
   "猻":"狲",
   "獁":"犸",
@@ -1148,6 +1171,7 @@ simplify={
   "睍":"𪾢",
   "睏":"困",
   "睞":"睐",
+  "睪":"睾",
   "瞘":"眍",
   "瞜":"䁖",
   "瞞":"瞒",
@@ -1177,6 +1201,7 @@ simplify={
   "礄":"硚",
   "礎":"础",
   "礐":"𬒈",
+  "礒":"𥐟",
   "礙":"碍",
   "礦":"矿",
   "礪":"砺",
@@ -1228,9 +1253,11 @@ simplify={
   "竊":"窃",
   "竜":"龙",
   "竝":"并",
+  "竢":"俟",
   "竪":"竖",
   "競":"竞",
   "筆":"笔",
+  "筍":"笋",
   "筧":"笕",
   "筩":"筒",
   "筯":"箸",
@@ -1449,6 +1476,7 @@ simplify={
   "繊":"纤",
   "繋":"系",
   "繍":"绣",
+  "繐":"𰬸",
   "繒":"缯",
   "織":"织",
   "繕":"缮",
@@ -1482,6 +1510,7 @@ simplify={
   "纕":"𬙋",
   "纖":"纤",
   "纘":"缵",
+  "纚":"𫄥",
   "纜":"缆",
   "罃":"䓨",
   "罌":"罂",
@@ -1577,6 +1606,7 @@ simplify={
   "莢":"荚",
   "莧":"苋",
   "華":"华",
+  "菴":"庵",
   "萇":"苌",
   "萊":"莱",
   "萬":"万",
@@ -1596,6 +1626,8 @@ simplify={
   "蓧":"𦰏",
   "蓮":"莲",
   "蓯":"苁",
+  "蓴":"莼",
+  "蓴":"莼",
   "蓽":"荜",
   "蔄":"𬜬",
   "蔔":"卜",
@@ -1619,6 +1651,7 @@ simplify={
   "蕪":"芜",
   "蕭":"萧",
   "蕷":"蓣",
+  "薆":"𫉁",
   "薈":"荟",
   "薊":"蓟",
   "薌":"芗",
@@ -1663,6 +1696,7 @@ simplify={
   "虧":"亏",
   "蛍":"萤",
   "蛺":"蛱",
+  "蛻":"蜕",
   "蜆":"蚬",
   "蜋":"螂",
   "蝀":"𬟽",
@@ -1820,6 +1854,7 @@ simplify={
   "詷":"𫍣",
   "詼":"诙",
   "詿":"诖",
+  "誂":"𫍥",
   "誄":"诔",
   "誅":"诛",
   "誆":"诓",
@@ -2125,6 +2160,7 @@ simplify={
   "轡":"辔",
   "轢":"轹",
   "轤":"轳",
+  "辠":"罪",
   "辦":"办",
   "辭":"辞",
   "辮":"辫",
@@ -2225,6 +2261,7 @@ simplify={
   "鈇":"𫓧",
   "鈈":"钚",
   "鈉":"钠",
+  "鈋":"𨱂",
   "鈍":"钝",
   "鈎":"钩",
   "鈐":"钤",
@@ -2385,6 +2422,7 @@ simplify={
   "鎄":"锿",
   "鎇":"镅",
   "鎊":"镑",
+  "鎌":"镰",
   "鎓":"𬭩",
   "鎔":"镕",
   "鎖":"锁",
@@ -2465,6 +2503,7 @@ simplify={
   "鑒":"鉴",
   "鑔":"镲",
   "鑕":"锧",
+  "鑚":"钻",
   "鑞":"镴",
   "鑠":"铄",
   "鑣":"镳",
@@ -2543,6 +2582,7 @@ simplify={
   "阬":"坑",
   "陘":"陉",
   "陝":"陕",
+  "陞":"升",
   "陣":"阵",
   "陥":"陷",
   "陰":"阴",
@@ -2842,6 +2882,7 @@ simplify={
   "鬧":"闹",
   "鬨":"哄",
   "鬩":"阋",
+  "鬪":"斗",
   "鬭":"斗",
   "鬮":"阄",
   "鬱":"郁",
@@ -3043,6 +3084,7 @@ simplify={
   "鷉":"䴘",
   "鷊":"鹝",
   "鷓":"鹧",
+  "鷖":"鹥",
   "鷗":"鸥",
   "鷙":"鸷",
   "鷚":"鹨",
